@@ -1,12 +1,15 @@
 import pytest
 import random
 import spacy
+import faker
 import re
 import pandas as pd
-from hover.utils.datasets import newsgroups_dictl
+from hover.utils.datasets import newsgroups_dictl, newsgroups_reduced_dictl
 from hover.core.dataset import SupervisableTextDataset
 from copy import deepcopy
 
+fake_en = faker.Faker("en")
+
 
 @pytest.fixture(scope="module")
 def spacy_en_md():
@@ -28,9 +31,27 @@ def dummy_vectorizer(spacy_en_md):
     return vectorizer
 
 
+@pytest.fixture(scope="module")
+def generate_text_df_with_coords():
+    def random_text_df_with_coords(size=300):
+        df = pd.DataFrame(
+            [
+                {
+                    "text": fake_en.paragraph(3),
+                    "x": random.uniform(-1.0, 1.0),
+                    "y": random.uniform(-1.0, 1.0),
+                }
+                for i in range(300)
+            ]
+        )
+        return df
+
+    return random_text_df_with_coords
+
+
 @pytest.fixture(scope="module")
 def mini_df_text():
-    my_20ng, _, _ = newsgroups_dictl()
+    my_20ng, _, _ = newsgroups_reduced_dictl()
 
     mini_dictl = random.sample(my_20ng["train"], k=1000)
     mini_df = pd.DataFrame(mini_dictl)
